abacusai.finetuned_pretrained_model — AbacusAI documentation

# abacusai.finetuned_pretrained_model

## Classes

`FinetunedPretrainedModel` | A finetuned pretrained model

## Module Contents

class abacusai.finetuned_pretrained_model.FinetunedPretrainedModel(client, name=None, finetunedPretrainedModelId=None, finetunedPretrainedModelVersion=None, createdAt=None, updatedAt=None, config=None, baseModel=None, finetuningDatasetVersion=None, status=None, error=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A finetuned pretrained model

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The user-friendly name for the model.

    - finetunedPretrainedModelId (str) – The unique identifier of the model.

    - finetunedPretrainedModelVersion (str) – The unique identifier of the model version.

    - createdAt (str) – When the finetuned pretrained model was created.

    - updatedAt (str) – When the finetuned pretrained model was last updated.

    - config (dict) – The finetuned pretrained model configuration

    - baseModel (str) – The pretrained base model for fine tuning

    - finetuningDatasetVersion (str) – The finetuned dataset instance id of the model.

    - status (str) – The current status of the finetuned pretrained model.

    - error (str) – Relevant error if the status is FAILED.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict